changeset 14040:187735b53d52

Comment fixes.
author Karl Heuer <kwzh@gnu.org>
date Fri, 05 Jan 1996 22:21:28 +0000
parents 831c5fda97f4
children 9e2b7610eddd
files lisp/ange-ftp.el lisp/avoid.el lisp/completion.el lisp/dabbrev.el lisp/desktop.el lisp/dired-aux.el lisp/double.el lisp/ediff-merg.el lisp/ediff-mult.el lisp/ediff-util.el lisp/ediff.el lisp/emacs-lisp/bytecomp.el lisp/emacs-lisp/cl-indent.el lisp/emacs-lisp/cl-specs.el lisp/emacs-lisp/copyright.el lisp/emacs-lisp/eval-reg.el lisp/emacs-lock.el lisp/emerge.el lisp/emulation/edt-pc.el lisp/emulation/mlsupport.el lisp/emulation/pc-select.el lisp/emulation/viper-keym.el lisp/emulation/viper-util.el lisp/faces.el lisp/gnus-cite.el lisp/gnus-ems.el lisp/gnus-msg.el lisp/gnus-score.el lisp/ielm.el lisp/imenu.el lisp/ledit.el lisp/mail/rnews.el lisp/mail/rnewspost.el lisp/man.el lisp/nnbabyl.el lisp/nneething.el lisp/nnfolder.el lisp/nnkiboze.el lisp/nnmbox.el lisp/nnmh.el lisp/nnml.el lisp/nnspool.el lisp/nntp.el lisp/play/gomoku.el lisp/play/mpuz.el lisp/progmodes/f90.el lisp/progmodes/perl-mode.el lisp/ps-print.el lisp/s-region.el lisp/sun-fns.el lisp/tar-mode.el lisp/term/pc-win.el lisp/textmodes/ispell.el lisp/textmodes/ooutline.el lisp/textmodes/outline.el lisp/textmodes/page-ext.el lisp/textmodes/texinfmt.el lisp/vc-hooks.el lisp/vc.el
diffstat 59 files changed, 94 insertions(+), 95 deletions(-) [+]
line wrap: on
line diff
--- a/lisp/ange-ftp.el	Fri Jan 05 21:57:54 1996 +0000
+++ b/lisp/ange-ftp.el	Fri Jan 05 22:21:28 1996 +0000
@@ -395,7 +395,7 @@
 ;;;    when asked to list a non-existent directory.  Some of the ai.mit.edu
 ;;;    machines cause this problem for some FTP clients. Using
 ;;;    ange-ftp-kill-ftp-process can restart the ftp process, which
-;;;    should get things back in synch.
+;;;    should get things back in sync.
 ;;;
 ;;; 3. Ange-ftp does not check to make sure that when creating a new file,
 ;;;    you provide a valid filename for the remote operating system.
@@ -2242,7 +2242,7 @@
 ;; 
 ;; With no-error t, it returns:
 ;; an error if not an ange-ftp-name
-;; error if listing is unreable (most likely caused by a slow connection)
+;; error if listing is unreadable (most likely caused by a slow connection)
 ;; nil if ftp error (this is because although asking to list a nonexistent
 ;;                   directory on a remote unix machine usually (except
 ;;                   maybe for dumb hosts) returns an ls error, but no
--- a/lisp/avoid.el	Fri Jan 05 21:57:54 1996 +0000
+++ b/lisp/avoid.el	Fri Jan 05 22:21:28 1996 +0000
@@ -166,7 +166,7 @@
   ;; Args are the CURRENT location, the desired DELTA for
   ;; warp-conservation, the DISTANCE we like to move, the VARIABILITY
   ;; in distance allowed, and the MIN and MAX possible window positions.
-  ;; Returns something as close to DELTA as possible withing the constraints.
+  ;; Returns something as close to DELTA as possible within the constraints.
   (let ((L1 (max (- min cur) (+ (- dist) (- var))))
 	(R1                  (+ (- dist)    var ))
 	(L2                  (+    dist  (- var)))
--- a/lisp/completion.el	Fri Jan 05 21:57:54 1996 +0000
+++ b/lisp/completion.el	Fri Jan 05 22:21:28 1996 +0000
@@ -221,7 +221,7 @@
 ;;;    With input from many users at TMC, (rose, craig, and gls come to mind),
 ;;; the current style of interface was developed. 
 ;;;    9/87, Jim and Brewster took terminals home.  Yuck.  After 
-;;; complaining for a while Brewester implemented a subset of the current 
+;;; complaining for a while Brewster implemented a subset of the current 
 ;;; LISPM version for GNU Emacs.  
 ;;;    8/88  After complaining for a while (and with sufficient 
 ;;; promised rewards), Jim reimplemented a version of GNU completion
@@ -1045,7 +1045,7 @@
 ;;; A completion entry is a LIST of string, prefix-symbol num-uses, and
 ;;; last-use-time (the time the completion was last used)
 ;;; last-use-time is T if the string should be kept permanently
-;;; num-uses is incremented everytime the completion is used.
+;;; num-uses is incremented every time the completion is used.
 
 ;;; We chose lists because (car foo) is faster than (aref foo 0) and the 
 ;;; creation time is about the same.
--- a/lisp/dabbrev.el	Fri Jan 05 21:57:54 1996 +0000
+++ b/lisp/dabbrev.el	Fri Jan 05 22:21:28 1996 +0000
@@ -41,7 +41,7 @@
 ;;
 ;; Set the variables you want special for your mode like this:
 ;; (set (make-local-variable 'dabbrev-case-replace) nil)
-;; Then you don't interfer with other modes.
+;; Then you don't interfere with other modes.
 ;;
 ;; If your mode handles buffers that refers to other buffers
 ;; (i.e. compilation-mode, gud-mode), then try to set
@@ -771,7 +771,7 @@
 
 ;;; ABBREV is string to find as prefix of word.  Second arg, REVERSE,
 ;;; is t for reverse search, nil for forward.  Variable dabbrev-limit
-;;; controls the maximum search region size.  Third argment IGNORE-CASE
+;;; controls the maximum search region size.  Third argument IGNORE-CASE
 ;;; non-nil means treat case as insignificant while looking for a match
 ;;; and when comparing with previous matches.  Also if that's non-nil
 ;;; and the match is found at the beginning of a sentence and is in
--- a/lisp/desktop.el	Fri Jan 05 21:57:54 1996 +0000
+++ b/lisp/desktop.el	Fri Jan 05 22:21:28 1996 +0000
@@ -144,7 +144,7 @@
 (make-variable-buffer-local 'desktop-locals-to-save)
 
 ;; We skip .log files because they are normally temporary.
-;;         (ftp) files because they require passwords and whatsnot.
+;;         (ftp) files because they require passwords and whatnot.
 ;;         TAGS files to save time (tags-file-name is saved instead).
 (defvar desktop-buffers-not-to-save
  "\\(^nn\\.a[0-9]+\\|\\.log\\|(ftp)\\|^tags\\|^TAGS\\)$"
--- a/lisp/dired-aux.el	Fri Jan 05 21:57:54 1996 +0000
+++ b/lisp/dired-aux.el	Fri Jan 05 22:21:28 1996 +0000
@@ -1008,7 +1008,7 @@
 ;; which will be added.  The user will be queried if the file already
 ;; exists.  If oldfile is removed by FILE-CREATOR (i.e, it is a
 ;; rename), it is FILE-CREATOR's responsibility to update dired
-;; buffers.  FILE-CREATOR must abort by signalling a file-error if it
+;; buffers.  FILE-CREATOR must abort by signaling a file-error if it
 ;; could not create newfile.  The error is caught and logged.
 
 ;; OPERATION (a capitalized string, e.g. `Copy') describes the
--- a/lisp/double.el	Fri Jan 05 21:57:54 1996 +0000
+++ b/lisp/double.el	Fri Jan 05 22:21:28 1996 +0000
@@ -33,7 +33,7 @@
 ;; string will be replaced by another.  This can be used for mapping
 ;; keys on a US keyboard to generate characters according to the local
 ;; keyboard convention when pressed once, and according to US keyboard
-;; convetion when pressed twice. 
+;; convention when pressed twice. 
 ;;
 ;; To use this mode, you must define the variable `double-map' and
 ;; then enable double mode with `M-x double-mode'.  Read the
@@ -42,9 +42,9 @@
 ;; The default mapping is for getting Danish/Norwegian keyboard layout
 ;; using ISO Latin 1 on a US keyboard.
 ;;
-;; Imprtant node: While I would like to hear comments, bug reports,
+;; Important node: While I would like to hear comments, bug reports,
 ;; suggestions, please do @strong{not} expect me to put other mappings
-;; that the default into this file.  There are billions and billions
+;; than the default into this file.  There are billions and billions
 ;; of such mappings, and just supporting the most common would
 ;; increase the size of this nice small file manyfold.
 
--- a/lisp/ediff-merg.el	Fri Jan 05 21:57:54 1996 +0000
+++ b/lisp/ediff-merg.el	Fri Jan 05 22:21:28 1996 +0000
@@ -137,7 +137,7 @@
 		    (and (string= state-of-merge "combined")
 			 (not (string=
 			       (ediff-make-combined-diff reg-A reg-B) reg-C)))
-		    ;; was prefered--ignore
+		    ;; was preferred--ignore
 		    (string-match "prefer" state-of-merge))
 		(setq do-not-copy t))
 		
--- a/lisp/ediff-mult.el	Fri Jan 05 21:57:54 1996 +0000
+++ b/lisp/ediff-mult.el	Fri Jan 05 22:21:28 1996 +0000
@@ -43,7 +43,7 @@
 ;;	   Actually, the format of this list is pretty much up to the
 ;;	   developer. The only thing is that it must be a list of lists.
 ;;	   Also, keep in mind that the function ediff-prepare-meta-buffer
-;;	   (which see) prepends nil in fron of each list (i.e., the above list
+;;	   (which see) prepends nil in front of each list (i.e., the above list
 ;;	   will become ((nil obj1 obj2 ...) (nil ...) ...).
 ;;	   Ediff expects that your function (in 2 above) will arrange to
 ;;	   replace this prepended nil (via setcar) with the actual ediff
@@ -1209,7 +1209,7 @@
       (error "No active Ediff sessions or corrupted session registry"))
   (let (wind frame)
     ;; for some reason, point moves in ediff-registry-buffer, so we preserve it
-    ;; explicity
+    ;; explictly
     (ediff-eval-in-buffer ediff-registry-buffer
       (save-excursion
 	(cond  ((setq wind
--- a/lisp/ediff-util.el	Fri Jan 05 21:57:54 1996 +0000
+++ b/lisp/ediff-util.el	Fri Jan 05 22:21:28 1996 +0000
@@ -733,7 +733,7 @@
 		       ediff-patch-action
 		       ediff-toggle-wide-display ediff-toggle-multiframe))
 	       ;; Or one of the movement cmds and prev cmd was an Ediff cmd
-	       ;; This avoids rasing frames unnecessarily.
+	       ;; This avoids raising frames unnecessarily.
 	       (and (memq this-command
 			  '(ediff-next-difference
 			    ediff-previous-difference
@@ -1420,7 +1420,7 @@
 				(move-to-window-line lines)
 				(point)))
 		       ;; `end' may be beyond the window bottom, so check
-		       ;; that we are making progres
+		       ;; that we are making progress
 		       (< prev-point (point)))
 	    (setq prev-point (point))
 	    (setq lines (1+ lines)))
@@ -2962,7 +2962,7 @@
 
 ;;; Misc
 
-;; These two functions are here to neutralize XEmacs unwillingless to
+;; These two functions are here to neutralize XEmacs's unwillingness to
 ;; handle overlays whose buffers were deleted.
 (defun ediff-move-overlay (overlay beg end &optional buffer)
   "Calls `move-overlay' in Emacs and `set-extent-endpoints' in Lemacs.
--- a/lisp/emacs-lisp/bytecomp.el	Fri Jan 05 21:57:54 1996 +0000
+++ b/lisp/emacs-lisp/bytecomp.el	Fri Jan 05 22:21:28 1996 +0000
@@ -938,7 +938,7 @@
 (defun byte-compile-arglist-signatures-congruent-p (old new)
   (not (or
 	 (> (car new) (car old))  ; requires more args now
-	 (and (null (cdr old))    ; tooks rest-args, doesn't any more
+	 (and (null (cdr old))    ; took rest-args, doesn't any more
 	      (cdr new))
 	 (and (cdr new) (cdr old) ; can't take as many args now
 	      (< (cdr new) (cdr old)))
@@ -1381,7 +1381,7 @@
 	;; Compile pending forms at end of file.
 	(byte-compile-flush-pending)
 	(byte-compile-warn-about-unresolved-functions)
-	;; SHould we always do this?  When calling multiple files, it
+	;; Should we always do this?  When calling multiple files, it
 	;; would be useful to delay this warning until all have
 	;; been compiled.
 	(setq byte-compile-unresolved-functions nil))))
--- a/lisp/emacs-lisp/cl-indent.el	Fri Jan 05 21:57:54 1996 +0000
+++ b/lisp/emacs-lisp/cl-indent.el	Fri Jan 05 22:21:28 1996 +0000
@@ -2,7 +2,7 @@
 
 ;; Copyright (C) 1987 Free Software Foundation, Inc.
 
-;; Author: Richard Mlynark <mly@eddie.mit.edu>
+;; Author: Richard Mlynarik <mly@eddie.mit.edu>
 ;; Created: July 1987
 ;; Maintainer: FSF
 ;; Keywords: lisp, tools
--- a/lisp/emacs-lisp/cl-specs.el	Fri Jan 05 21:57:54 1996 +0000
+++ b/lisp/emacs-lisp/cl-specs.el	Fri Jan 05 22:21:28 1996 +0000
@@ -7,7 +7,7 @@
 ;; LCD Archive Entry:
 ;; cl-specs.el|Daniel LaLiberte|liberte@cs.uiuc.edu
 ;; |Edebug specs for cl.el
-;; |$Date: 1995/04/19 00:47:42 $|1.1|
+;; |$Date: 1995/10/30 16:51:55 $|1.1|
 
 ;; This file is part of GNU Emacs.
 
@@ -30,7 +30,7 @@
 ;; These specs are to be used with edebug.el version 3.3 or later and
 ;; cl.el version 2.03 or later, by Dave Gillespie <daveg@synaptics.com>.
 
-;; This file need not be byte-compiled, but it shouldnt hurt.
+;; This file need not be byte-compiled, but it shouldn't hurt.
 
 (provide 'cl-specs)
 ;; Do the above provide before the following require.
@@ -412,7 +412,7 @@
 
 (def-edebug-spec loop-initial-final
   (&or ["initially" 
-	;; [&optional &or "do" "doing"]  ;; CLtL2 doesnt allow this.
+	;; [&optional &or "do" "doing"]  ;; CLtL2 doesn't allow this.
 	&rest loop-non-atomic-expr]
        ["finally" &or 
 	[[&optional &or "do" "doing"] &rest loop-non-atomic-expr]
--- a/lisp/emacs-lisp/copyright.el	Fri Jan 05 21:57:54 1996 +0000
+++ b/lisp/emacs-lisp/copyright.el	Fri Jan 05 22:21:28 1996 +0000
@@ -48,7 +48,7 @@
   "String representing the current year.")
 
 
-;; when modifiying this, also modify the comment generated by autoinsert.el
+;; when modifying this, also modify the comment generated by autoinsert.el
 (defconst copyright-current-gpl-version "2"
   "String representing the current version of the GPL or `nil'.")
 
--- a/lisp/emacs-lisp/eval-reg.el	Fri Jan 05 21:57:54 1996 +0000
+++ b/lisp/emacs-lisp/eval-reg.el	Fri Jan 05 22:21:28 1996 +0000
@@ -130,7 +130,7 @@
 This version, from `eval-reg.el', allows Lisp customization of read,
 eval, and the printer."
 
-  ;; Because this doesnt narrow to the region, one other difference 
+  ;; Because this doesn't narrow to the region, one other difference 
   ;; concerns inserting whitespace after the expression being evaluated.
 
   (interactive "r")
@@ -138,7 +138,7 @@
       (original-eval-region elisp-start elisp-end elisp-output)
     (let ((elisp-pnt (point))
 	  (elisp-buf (current-buffer));; Outside buffer
-	  (elisp-inside-buf (current-buffer));; Buffer current while evaling
+	  (elisp-inside-buf (current-buffer));; Buffer current while evalling
 	  ;; Mark the end because it may move.
 	  (elisp-end-marker (set-marker (make-marker) elisp-end))
 	  elisp-form
--- a/lisp/emacs-lock.el	Fri Jan 05 21:57:54 1996 +0000
+++ b/lisp/emacs-lock.el	Fri Jan 05 22:21:28 1996 +0000
@@ -28,7 +28,7 @@
 ;; yourself from yourself.  For example, if you have a shell running a big
 ;; program and exiting emacs would abort that program, you may want to lock
 ;; that buffer, then if you forget about it after a while, you won't
-;; accidently exit emacs.  To unlock the buffer, just goto the buffer and
+;; accidentally exit emacs.  To unlock the buffer, just goto the buffer and
 ;; run toggle-emacs-lock again.
 
 (defvar lock-emacs-from-exiting nil
--- a/lisp/emerge.el	Fri Jan 05 21:57:54 1996 +0000
+++ b/lisp/emerge.el	Fri Jan 05 22:21:28 1996 +0000
@@ -1741,7 +1741,7 @@
 ;; If there are min-lines lines above and below the region, then don't do
 ;; anything.
 ;; If not, recenter the region to make it so.
-;; If that isn't possible, remove context lines balancedly from top and botton
+;; If that isn't possible, remove context lines balancedly from top and bottom
 ;; so the entire region shows.
 ;; If that isn't possible, show the top of the region.
 ;; BEG must be at the beginning of a line.
@@ -2847,7 +2847,7 @@
 ;; a list of variables.  The argument is a list of symbols (the names of
 ;; the variables).  A list element can also be a list of two functions,
 ;; the first of which (when called with no arguments) gets the value, and
-;; the second (when called with a value as an argment) sets the value.
+;; the second (when called with a value as an argument) sets the value.
 ;; A "function" is anything that funcall can handle as an argument.
 
 (defun emerge-save-variables (vars)
--- a/lisp/emulation/edt-pc.el	Fri Jan 05 21:57:54 1996 +0000
+++ b/lisp/emulation/edt-pc.el	Fri Jan 05 22:21:28 1996 +0000
@@ -38,7 +38,7 @@
 ;; NumLock must be ON.
 ;;
 ;; The PC keypad keys are mapped to the corresponding DEC LK-201
-;; keypad keys according to the corresponding physical possition on
+;; keypad keys according to the corresponding physical position on
 ;; the keyboard.  Thus, the physical position of the PC keypad key
 ;; determines its function, not the PC keycap name.
 ;;
--- a/lisp/emulation/mlsupport.el	Fri Jan 05 21:57:54 1996 +0000
+++ b/lisp/emulation/mlsupport.el	Fri Jan 05 22:21:28 1996 +0000
@@ -26,7 +26,7 @@
 ;; This package provides equivalents of certain primitives from Gosling
 ;; Emacs (including the commercial UniPress versions).  These have an
 ;; ml- prefix to distinguish them from native GNU Emacs functions with
-;; similar names.  The oackage mlconvert.el translates Mocklisp code
+;; similar names.  The package mlconvert.el translates Mocklisp code
 ;; to use these names.
 
 ;;; Code:
--- a/lisp/emulation/pc-select.el	Fri Jan 05 21:57:54 1996 +0000
+++ b/lisp/emulation/pc-select.el	Fri Jan 05 22:21:28 1996 +0000
@@ -494,7 +494,7 @@
   (define-key global-map "\M-w" 'copy-region-as-kill-nomark) 
 
 
-  ;; The followong keybindings are for standard ISO keyboards
+  ;; The following keybindings are for standard ISO keyboards
   ;; as they are used with IBM compatible PCs, IBM RS/6000,
   ;; MACs, many X-Stations and probably more
   (define-key global-map [S-right]   'forward-char-mark)
@@ -533,7 +533,7 @@
   (define-key global-map [C-insert]  'copy-region-as-kill)
   (define-key global-map [S-delete]  'kill-region)
 
-  ;; The following bindings are usueful on Sun Type 3 keyboards
+  ;; The following bindings are useful on Sun Type 3 keyboards
   ;; They implement the Get-Delete-Put (copy-cut-paste)
   ;; functions from sunview on the L6, L8 and L10 keys
   (define-key global-map [f16]  'yank)
--- a/lisp/emulation/viper-keym.el	Fri Jan 05 21:57:54 1996 +0000
+++ b/lisp/emulation/viper-keym.el	Fri Jan 05 22:21:28 1996 +0000
@@ -31,8 +31,7 @@
 (defvar vip-insert-intercept-map (make-sparse-keymap))
 (defvar vip-emacs-intercept-map (make-sparse-keymap))
 
-;; keymap used to zap all keymaps other than function-key-map,
-;; devide-function-key-map, etc.
+;; keymap used to zap all keymaps other than function-key-map, etc.
 (defvar vip-overriding-map (make-sparse-keymap))
   
 (vip-deflocalvar vip-vi-local-user-map (make-sparse-keymap)
--- a/lisp/emulation/viper-util.el	Fri Jan 05 21:57:54 1996 +0000
+++ b/lisp/emulation/viper-util.el	Fri Jan 05 22:21:28 1996 +0000
@@ -766,7 +766,7 @@
 
 
 ;; Emacs has a bug in eventp, which causes (eventp nil) to return (nil)
-;; instead of nil, if '(nil) was previously inadvertantly assigned to
+;; instead of nil, if '(nil) was previously inadvertently assigned to
 ;; unread-command-events
 (defun vip-event-key (event)
   (or (and event (eventp event))
--- a/lisp/faces.el	Fri Jan 05 21:57:54 1996 +0000
+++ b/lisp/faces.el	Fri Jan 05 22:21:28 1996 +0000
@@ -150,7 +150,7 @@
   ;; For a specific frame, use gray stipple instead of gray color
   ;; if the display does not support a gray color.
   (if (and frame (not (eq frame t)) color
-	   ;; Check for supportedness for foreground, not for background!
+	   ;; Check for support for foreground, not for background!
 	   ;; face-color-supported-p is smart enough to know
 	   ;; that grays are "supported" as background
 	   ;; because we are supposed to use stipple for them!
--- a/lisp/gnus-cite.el	Fri Jan 05 21:57:54 1996 +0000
+++ b/lisp/gnus-cite.el	Fri Jan 05 22:21:28 1996 +0000
@@ -452,12 +452,12 @@
   ;; loose attribution lines, otherwise the first prefix will be used.
   ;;
   ;; If AFTER is non-nil, only citations after the attribution line
-  ;; will be concidered.
+  ;; will be considered.
   ;;
   ;; If FUN is non-nil, it will be called with the arguments (WROTE
   ;; PREFIX TAG) and expected to return a regular expression.  Only
   ;; citations whose prefix matches the regular expression will be
-  ;; concidered. 
+  ;; considered. 
   ;; 
   ;; WROTE is the attribution line number.
   ;; PREFIX is the attribution line prefix.
--- a/lisp/gnus-ems.el	Fri Jan 05 21:57:54 1996 +0000
+++ b/lisp/gnus-ems.el	Fri Jan 05 22:21:28 1996 +0000
@@ -415,7 +415,7 @@
 	  ;; Fucking XEmacs redisplay bug with truncated lines.
 	  (goto-char b)
 	  (sit-for 0)
-	  ;; Grumble.. Fucking XEmacs stickyness of text properties.
+	  ;; Grumble.. Fucking XEmacs stickiness of text properties.
 	  (remove-text-properties
 	   (1+ b) (1+ (gnus-point-at-eol))
 	   '(gnus-number nil gnus-mark nil gnus-level nil))
--- a/lisp/gnus-msg.el	Fri Jan 05 21:57:54 1996 +0000
+++ b/lisp/gnus-msg.el	Fri Jan 05 22:21:28 1996 +0000
@@ -580,7 +580,7 @@
 	   (match-beginning 0)))
 
 	;; Correct newsgroups field: change sequence of spaces to comma and 
-	;; eliminate spaces around commas.  Eliminate imbedded line breaks.
+	;; eliminate spaces around commas.  Eliminate embedded line breaks.
 	(goto-char (point-min))
 	(if (re-search-forward "^Newsgroups: +" nil t)
 	    (save-restriction
@@ -1353,7 +1353,7 @@
 ;; You might for example insert a "." somewhere (not next to another dot
 ;; or string boundary), or modify the newsreader name to "Ding".
 (defun gnus-inews-unique-id ()
-  ;; Dont use microseconds from (current-time), they may be unsupported.
+  ;; Don't use microseconds from (current-time), they may be unsupported.
   ;; Instead we use this randomly inited counter.
   (setq gnus-unique-id-char
 	(% (1+ (or gnus-unique-id-char (logand (random t) (1- (lsh 1 20)))))
--- a/lisp/gnus-score.el	Fri Jan 05 21:57:54 1996 +0000
+++ b/lisp/gnus-score.el	Fri Jan 05 22:21:28 1996 +0000
@@ -910,7 +910,7 @@
             (if last
                 (progn
                   ;; Insert the line, with a text property on the
-                  ;; terminating newline refering to the articles with
+                  ;; terminating newline referring to the articles with
                   ;; this line.
                   (insert last ?\n)
                   (put-text-property (1- (point)) (point) 'articles alike)))
@@ -1252,7 +1252,7 @@
 
 (defun gnus-score-string (score-list header now expire &optional trace)
   ;; Score ARTICLES according to HEADER in SCORE-LIST.
-  ;; Update matches entries to NOW and remove unmatched entried older
+  ;; Update matching entries to NOW and remove unmatched entries older
   ;; than EXPIRE.
   
   ;; Insert the unique article headers in the buffer.
@@ -1281,7 +1281,7 @@
 	(if last
 	    (progn
 	      ;; Insert the line, with a text property on the
-	      ;; terminating newline refering to the articles with
+	      ;; terminating newline referring to the articles with
 	      ;; this line.
 	      (insert last ?\n)
 	      (put-text-property (1- (point)) (point) 'articles alike)))
--- a/lisp/ielm.el	Fri Jan 05 21:57:54 1996 +0000
+++ b/lisp/ielm.el	Fri Jan 05 22:21:28 1996 +0000
@@ -87,7 +87,7 @@
 (defvar ielm-header 
   (concat
    "*** Welcome to IELM version "
-   (substring "$Revision: 1.4 $" 11 -2)
+   (substring "$Revision: 1.5 $" 11 -2)
    " ***  Type (describe-mode) for help.\n"
    "IELM has ABSOLUTELY NO WARRANTY; type (describe-no-warranty) for details.\n")
   "Message to display when IELM is started.")
@@ -145,7 +145,7 @@
     (or 
      ;; the buffer has been modified
      (not (= btick (buffer-modified-tick))) 
-     ;; a completions buffer has been modifed or created
+     ;; a completions buffer has been modified or created
      (if cbuffer
 	 (not (= ctick (buffer-modified-tick cbuffer)))
        (get-buffer "*Completions*")))))
--- a/lisp/imenu.el	Fri Jan 05 21:57:54 1996 +0000
+++ b/lisp/imenu.el	Fri Jan 05 22:21:28 1996 +0000
@@ -369,7 +369,7 @@
       (/ (* 100 (1- pos)) (max total 1)))))
 
 ;;;
-;;; Function for suporting general looking submenu names.
+;;; Function for supporting general looking submenu names.
 ;;; Uses `imenu-submenu-name-format' for creating the name.
 ;;; NAME is the base of the new submenu name.
 ;;;
--- a/lisp/ledit.el	Fri Jan 05 21:57:54 1996 +0000
+++ b/lisp/ledit.el	Fri Jan 05 22:21:28 1996 +0000
@@ -3,7 +3,7 @@
 ;; Copyright (C) 1985 Free Software Foundation, Inc.
 
 ;; Maintainer: FSF
-;; Keyord: languages
+;; Keyword: languages
 
 ;; This file is part of GNU Emacs.
 
--- a/lisp/mail/rnews.el	Fri Jan 05 21:57:54 1996 +0000
+++ b/lisp/mail/rnews.el	Fri Jan 05 22:21:28 1996 +0000
@@ -43,7 +43,7 @@
 ;; 	tower@prep Sep  3 1986
 ;; added news-rotate-buffer-body
 ;;	tower@prep Oct 17 1986
-;; made messages more user friendly, cleanuped news-inews
+;; made messages more user friendly, cleaned up news-inews
 ;; move posting and mail code to new file rnewpost.el
 ;;	tower@prep Oct 29 1986
 ;; added caesar-region, rename news-caesar-buffer-body, hacked accordingly
@@ -796,7 +796,7 @@
 	       (setq tem news-list-of-files)
 	       (while tem
 		 (if (or (not (string-match "^[0-9]*$" (car tem)))
-			 ;; dont get confused by directories that look like numbers
+			 ;; don't get confused by directories that look like numbers
 			 (file-directory-p
 			  (concat file-directory "/" (car tem)))
 			 (<= (string-to-int (car tem)) end-file-no))
@@ -858,7 +858,7 @@
 (defun news-add-news-group (gp)
   "Resubscribe to or add a USENET news group named GROUP (a string)."
 ; @@ (completing-read ...)
-; @@ could be based on news library file ../active (slightly facist)
+; @@ could be based on news library file ../active (slightly fascist)
 ; @@ or (expensive to compute) all directories under the news spool directory
   (interactive "sAdd news group: ")
   (let ((file-dir (concat news-path (string-subst-char ?/ ?. gp))))
--- a/lisp/mail/rnewspost.el	Fri Jan 05 21:57:54 1996 +0000
+++ b/lisp/mail/rnewspost.el	Fri Jan 05 22:21:28 1996 +0000
@@ -46,7 +46,7 @@
 ;; imported from rmail and modified to work with rnews ...
 ;; Mon Mar 25,1985 at 03:07:04 ads@mit-hermes.
 ;; this is done so that rnews can operate independently from rmail.el and
-;; sendmail and dosen't have to autoload these functions.
+;; sendmail and doesn't have to autoload these functions.
 ;;
 ;;; >> Nuked by Mly to autoload those functions again, as the duplication of
 ;;; >>  code was making maintenance too difficult.
--- a/lisp/man.el	Fri Jan 05 21:57:54 1996 +0000
+++ b/lisp/man.el	Fri Jan 05 22:21:28 1996 +0000
@@ -35,7 +35,7 @@
 ;; ========== Credits and History ========== 
 ;; In mid 1991, several people posted some interesting improvements to
 ;; man.el from the standard emacs 18.57 distribution.  I liked many of
-;; these, but wanted everthing in one single package, so I decided
+;; these, but wanted everything in one single package, so I decided
 ;; to incorporate them into a single manual browsing mode.  While
 ;; much of the code here has been rewritten, and some features added,
 ;; these folks deserve lots of credit for providing the initial
@@ -56,7 +56,7 @@
 
 ;; Francesco Potorti` <pot@cnuce.cnr.it> cleaned it up thoroughly,
 ;; making it faster, more robust and more tolerant of different
-;; systems' man idiosynchrasies.
+;; systems' man idiosyncrasies.
 
 ;; ========== Features ==========
 ;; + Runs "man" in the background and pipes the results through a
--- a/lisp/nnbabyl.el	Fri Jan 05 21:57:54 1996 +0000
+++ b/lisp/nnbabyl.el	Fri Jan 05 22:21:28 1996 +0000
@@ -354,7 +354,7 @@
 
 ;; If FORCE, delete article no matter how many X-Gnus-Newsgroup
 ;; headers there are. If LEAVE-DELIM, don't delete the Unix mbox
-;; delimeter line.
+;; delimiter line.
 (defun nnbabyl-delete-mail (&optional force leave-delim)
   ;; Delete the current X-Gnus-Newsgroup line.
   (or force
--- a/lisp/nneething.el	Fri Jan 05 21:57:54 1996 +0000
+++ b/lisp/nneething.el	Fri Jan 05 22:21:28 1996 +0000
@@ -201,7 +201,7 @@
 		      nneething-group-alist)))))))
 
 (defun nneething-map-file ()
-  ;; We make sure that the .neething directory exists. 
+  ;; We make sure that the .nneething directory exists. 
   (make-directory nneething-map-file-directory 'parents)
   ;; We store it in a special directory under the user's home dir.
   (concat (file-name-as-directory nneething-map-file-directory)
--- a/lisp/nnfolder.el	Fri Jan 05 21:57:54 1996 +0000
+++ b/lisp/nnfolder.el	Fri Jan 05 22:21:28 1996 +0000
@@ -42,7 +42,7 @@
   (concat (file-name-as-directory nnfolder-directory) "active")
   "The name of the active file.")
 
-;; I renamed this variable to somehting more in keeping with the general GNU
+;; I renamed this variable to something more in keeping with the general GNU
 ;; style. -SLB
 
 (defvar nnfolder-ignore-active-file nil
@@ -566,7 +566,7 @@
 ;; accidentally gotten new mail with something other than Gnus (but why
 ;; would _that_ ever happen? :-).  In that case, we will be in the middle of
 ;; processing the file, ready to add new X-Gnus article number markers, and
-;; we'll run accross a message with no ID yet - the active list _may_not_ be
+;; we'll run across a message with no ID yet - the active list _may_not_ be
 ;; ready for us yet.
 
 ;; To handle this, I'm modifying this routine to maintain the maximum ID seen
@@ -593,7 +593,7 @@
 	  activenumber activemin start end)
       (goto-char (point-min))
       ;;
-      ;; Anytime the active number is 1 or 0, it is supect.  In that case,
+      ;; Anytime the active number is 1 or 0, it is suspect.  In that case,
       ;; search the file manually to find the active number.  Or, of course,
       ;; if we're being paranoid.  (This would also be the place to build
       ;; other lists from the header markers, such as expunge lists, etc., if
--- a/lisp/nnkiboze.el	Fri Jan 05 21:57:54 1996 +0000
+++ b/lisp/nnkiboze.el	Fri Jan 05 22:21:28 1996 +0000
@@ -101,7 +101,7 @@
   "Select article by message number."
   (nnkiboze-possibly-change-newsgroups newsgroup)
   (if (not (numberp article))
-      ;; This is a real cludge. It might not work at times, but it
+      ;; This is a real kludge. It might not work at times, but it
       ;; does no harm I think. The only alternative is to offer no
       ;; article fetching by message-id at all.
       (nntp-request-article article newsgroup gnus-nntp-server buffer)
--- a/lisp/nnmbox.el	Fri Jan 05 21:57:54 1996 +0000
+++ b/lisp/nnmbox.el	Fri Jan 05 22:21:28 1996 +0000
@@ -338,7 +338,7 @@
 
 ;; If FORCE, delete article no matter how many X-Gnus-Newsgroup
 ;; headers there are. If LEAVE-DELIM, don't delete the Unix mbox
-;; delimeter line.
+;; delimiter line.
 (defun nnmbox-delete-mail (&optional force leave-delim)
   ;; Delete the current X-Gnus-Newsgroup line.
   (or force
--- a/lisp/nnmh.el	Fri Jan 05 21:57:54 1996 +0000
+++ b/lisp/nnmh.el	Fri Jan 05 22:21:28 1996 +0000
@@ -311,7 +311,7 @@
       (and 
        (nnmail-activate 'nnmh)
        ;; We trick the choosing function into believing that only one
-       ;; group is availiable.  
+       ;; group is available.  
        (let ((nnmail-split-methods (list (list group ""))))
 	 (car (nnmh-save-mail))))
     (and
--- a/lisp/nnml.el	Fri Jan 05 21:57:54 1996 +0000
+++ b/lisp/nnml.el	Fri Jan 05 22:21:28 1996 +0000
@@ -327,7 +327,7 @@
 	(and 
 	 (nnmail-activate 'nnml)
 	 ;; We trick the choosing function into believing that only one
-	 ;; group is availiable.  
+	 ;; group is available.  
 	 (let ((nnmail-split-methods (list (list group ""))))
 	   (setq result (car (nnml-save-mail))))
 	 (progn
--- a/lisp/nnspool.el	Fri Jan 05 21:57:54 1996 +0000
+++ b/lisp/nnspool.el	Fri Jan 05 22:21:28 1996 +0000
@@ -366,7 +366,7 @@
 		(nnspool-sift-nov-with-sed articles nov)
 	      (insert-file-contents nov)
 	      ;; First we find the first wanted line. We issue a number
-	      ;; of search-forwards - the first article we are lookign
+	      ;; of search-forwards - the first article we are looking
 	      ;; for may be expired, so we have to go on searching until
 	      ;; we find one of the articles we want.
 	      (while (and articles
--- a/lisp/nntp.el	Fri Jan 05 21:57:54 1996 +0000
+++ b/lisp/nntp.el	Fri Jan 05 22:21:28 1996 +0000
@@ -326,7 +326,7 @@
       (if nntp-server-list-active-group
 	  (progn
 	    ;; We have read active entries, so we just delete the
-	    ;; superfluos gunk.
+	    ;; superfluous gunk.
 	    (goto-char (point-min))
 	    (while (re-search-forward "^[.2-5]" nil t)
 	      (delete-region (match-beginning 0) 
@@ -936,7 +936,7 @@
 		(accept-process-output)
 		;; On some Emacs versions the preceding function has
 		;; a tendency to change the buffer. Perhaps. It's
-		;; quite difficult to reporduce, because it only
+		;; quite difficult to reproduce, because it only
 		;; seems to happen once in a blue moon. 
 		(set-buffer buf) 
 		(while (progn
--- a/lisp/play/gomoku.el	Fri Jan 05 21:57:54 1996 +0000
+++ b/lisp/play/gomoku.el	Fri Jan 05 22:21:28 1996 +0000
@@ -266,8 +266,8 @@
 ;; please send me a note. Thanks.
 
 
-;; As we choosed values 0, 1 and 6 to denote empty, X and O squares, the
-;; contents of a qtuple is uniquely determined by the sum of its elements and
+;; As we chose values 0, 1 and 6 to denote empty, X and O squares, the
+;; contents of a qtuple are uniquely determined by the sum of its elements and
 ;; we just have to set up a translation table.
 
 (defconst gomoku-score-trans-table
--- a/lisp/play/mpuz.el	Fri Jan 05 21:57:54 1996 +0000
+++ b/lisp/play/mpuz.el	Fri Jan 05 22:21:28 1996 +0000
@@ -185,7 +185,7 @@
 		   D (* A (/ B 10))
 		   E (* A B))
 	     (or (< C 1000) (< D 1000)))) ; forbid leading zeros in C or D
-    ;; Individual digits are now put on their respectives squares.
+    ;; Individual digits are now put on their respective squares.
     ;; [NB: A square is a pair <row,column> of the screen.]
     (mpuz-put-digit-on-board A		 '(2 . 9))
     (mpuz-put-digit-on-board (/ A 10)	 '(2 . 7))
--- a/lisp/progmodes/f90.el	Fri Jan 05 21:57:54 1996 +0000
+++ b/lisp/progmodes/f90.el	Fri Jan 05 22:21:28 1996 +0000
@@ -248,7 +248,7 @@
   ;; "set_exponent" "shape" "sign" "sin" "sinh" "size" "spacing" "spread"
   ;; "sqrt" "sum" "system_clock" "tan" "tanh" "tiny" "transfer" "transpose"
   ;; "trim" "ubound" "unpack" "verify")
-  ;; A left paranthesis to avoid highlighting non-procedures.
+  ;; A left parenthesis to avoid highlighting non-procedures.
   ;; Real is taken out here to avoid highlighting declarations.
   (concat
    "\\<\\(a\\(bs\\|c\\(har\\|os\\)\\|djust[lr]\\|i\\(mag\\|nt\\)\\|ll\\(\\|"
--- a/lisp/progmodes/perl-mode.el	Fri Jan 05 21:57:54 1996 +0000
+++ b/lisp/progmodes/perl-mode.el	Fri Jan 05 22:21:28 1996 +0000
@@ -31,7 +31,7 @@
 ;; To enter perl-mode automatically, add (autoload 'perl-mode "perl-mode")
 ;; to your .emacs file and change the first line of your perl script to:
 ;; #!/usr/bin/perl --	 # -*-Perl-*-
-;; With argments to perl:
+;; With arguments to perl:
 ;; #!/usr/bin/perl -P-	 # -*-Perl-*-
 ;; To handle files included with do 'filename.pl';, add something like
 ;; (setq auto-mode-alist (append (list (cons "\\.pl\\'" 'perl-mode))
--- a/lisp/ps-print.el	Fri Jan 05 21:57:54 1996 +0000
+++ b/lisp/ps-print.el	Fri Jan 05 22:21:28 1996 +0000
@@ -83,7 +83,7 @@
 ;; printout than to find 50 single-page printouts).
 ;; 
 ;; Ps-print has a hook in the kill-emacs-hooks so that you won't
-;; accidently quit from Emacs while you have unprinted PostScript
+;; accidentally quit from Emacs while you have unprinted PostScript
 ;; waiting in the spool buffer.  If you do attempt to exit with
 ;; spooled PostScript, you'll be asked if you want to print it, and if
 ;; you decline, you'll be asked to confirm the exit; this is modeled
@@ -198,7 +198,7 @@
 ;; Ps-print keeps internal lists of which fonts are bold and which are
 ;; italic; these lists are built the first time you invoke ps-print.
 ;; For the sake of efficiency, the lists are built only once; the same
-;; lists are referred in later invokations of ps-print.
+;; lists are referred in later invocations of ps-print.
 ;;
 ;; Because these lists are built only once, it's possible for them to
 ;; get out of sync, if a face changes, or if new faces are added.  To
@@ -255,7 +255,7 @@
 ;; or variables.  Functions are called, and should return a string to
 ;; show in the header.  Variables should contain strings to display in
 ;; the header.  In either case, function or variable, the PostScript
-;; strings delimeters are added by ps-print, and should not be part of
+;; string delimiters are added by ps-print, and should not be part of
 ;; the returned value.
 ;;
 ;; Here's an example: say we want the left header to display the text
@@ -1836,7 +1836,7 @@
 	      ;; the postscript was generated without error.
 	      (setq completed-safely t))
 
-	  ;; Unwind form: If some bad mojo ocurred while generating
+	  ;; Unwind form: If some bad mojo occurred while generating
 	  ;; postscript, delete all the postscript that was generated.
 	  ;; This protects the previously spooled files from getting
 	  ;; corrupted.
--- a/lisp/s-region.el	Fri Jan 05 21:57:54 1996 +0000
+++ b/lisp/s-region.el	Fri Jan 05 22:21:28 1996 +0000
@@ -25,7 +25,7 @@
 
 ;; Having loaded this code you can set the region by holding down the
 ;; shift key and move the cursor to the other end of the region.  The
-;; functionallity provided by this code is similar to that provided by
+;; functionality provided by this code is similar to that provided by
 ;; the editors of Borland International's compilers for ms-dos.
 
 ;; Currently, s-region-move may be bound only to events that are vectors
--- a/lisp/sun-fns.el	Fri Jan 05 21:57:54 1996 +0000
+++ b/lisp/sun-fns.el	Fri Jan 05 22:21:28 1996 +0000
@@ -319,7 +319,7 @@
 relative X divided by window width."
   (eval-in-window window 
     (if (>= x (1- (window-width)))
-	;; When x is maximun (equal to or 1 less than window width),
+	;; When x is maximum (equal to or 1 less than window width),
 	;; goto end of buffer.  We check for this special case
 	;; because the calculated goto-char often goes short of the
 	;; end due to roundoff error, and we often really want to go
--- a/lisp/tar-mode.el	Fri Jan 05 21:57:54 1996 +0000
+++ b/lisp/tar-mode.el	Fri Jan 05 22:21:28 1996 +0000
@@ -851,7 +851,7 @@
       (let ((line-len (- (point) line-start)))
 	(delete-region line-start (point))
 	;;
-	;; decrement the header-pointer to be in synch...
+	;; decrement the header-pointer to be in sync...
 	(setq tar-header-offset (- tar-header-offset line-len))))
     ;;
     ;; delete the data pointer...
--- a/lisp/term/pc-win.el	Fri Jan 05 21:57:54 1996 +0000
+++ b/lisp/term/pc-win.el	Fri Jan 05 22:21:28 1996 +0000
@@ -102,7 +102,7 @@
 ;; We have only one font, so...
 (add-hook 'before-init-hook 'msdos-face-setup)
 ;; ---------------------------------------------------------------------------
-;; More or less useful immitations of certain X-functions.  A lot of the
+;; More or less useful imitations of certain X-functions.  A lot of the
 ;; values returned are questionable, but usually only the form of the
 ;; returned value matters.  Also, by the way, recall that `ignore' is
 ;; a useful function for returning 'nil regardless of argument.
--- a/lisp/textmodes/ispell.el	Fri Jan 05 21:57:54 1996 +0000
+++ b/lisp/textmodes/ispell.el	Fri Jan 05 22:21:28 1996 +0000
@@ -1324,7 +1324,7 @@
 ;;;   multiple lines.
 ;;; "ispell-filter-continue" is true when we have received only part of a
 ;;;   line as output from a generating function ("output" did not end with \n)
-;;; NOTE THAT THIS FUNCTION WILL FAIL IF THE PROCESS OUTPUT DOESNT END WITH \n!
+;;; THIS FUNCTION WILL FAIL IF THE PROCESS OUTPUT DOESN'T END WITH \n!
 ;;;   This is the case when a process dies or fails. The default behavior
 ;;;   in this case treats the next input received as fresh input.
 
@@ -1370,7 +1370,7 @@
 	(inhibit-quit t)		; inhibit interrupt processing here.
 	(buffer-undo-list t))		; don't clutter the undo list.
     (delete-region start end)
-    (insert-char ?  (- end start))	; mimimize amount of redisplay
+    (insert-char ?  (- end start))	; minimize amount of redisplay
     (sit-for 0)				; update display
     (if highlight (setq inverse-video (not inverse-video))) ; toggle video
     (delete-region start end)		; delete whitespace
@@ -2200,7 +2200,7 @@
 					(point))))
 		   (end (or (and end-c end-fwd (min end-c end-fwd))
 			    end-c end-fwd
-			    ;; defalut to limit of text.
+			    ;; default to limit of text.
 			    (marker-position limit))))
 	      (goto-char start)
 	      (ispell-region start end)
--- a/lisp/textmodes/ooutline.el	Fri Jan 05 21:57:54 1996 +0000
+++ b/lisp/textmodes/ooutline.el	Fri Jan 05 22:21:28 1996 +0000
@@ -145,7 +145,7 @@
 			       (3 . font-lock-comment-face))))
 	      font-lock-variable-name-face))
 	nil t))
-    ;; Highight citations of the form [1] and [Mar94].
+    ;; Highlight citations of the form [1] and [Mar94].
     ("\\[\\([A-Z][A-Za-z]+\\)*[0-9]+\\]" . font-lock-type-face))
   "Additional expressions to highlight in Outline mode.")
 
--- a/lisp/textmodes/outline.el	Fri Jan 05 21:57:54 1996 +0000
+++ b/lisp/textmodes/outline.el	Fri Jan 05 22:21:28 1996 +0000
@@ -145,7 +145,7 @@
 			       (3 . font-lock-comment-face))))
 	      font-lock-variable-name-face))
 	nil t))
-    ;; Highight citations of the form [1] and [Mar94].
+    ;; Highlight citations of the form [1] and [Mar94].
     ("\\[\\([A-Z][A-Za-z]+\\)*[0-9]+\\]" . font-lock-type-face))
   "Additional expressions to highlight in Outline mode.")
 
--- a/lisp/textmodes/page-ext.el	Fri Jan 05 21:57:54 1996 +0000
+++ b/lisp/textmodes/page-ext.el	Fri Jan 05 22:21:28 1996 +0000
@@ -161,7 +161,7 @@
 
 ; You may use either the `C-x C-p d' (pages-directory-for-addresses)
 ; or the `C-x C-p C-d' (pages-directory) command to construct and
-; dislay a directory of all the heading lines.
+; display a directory of all the heading lines.
 
 ; In the directory, you may position the cursor over a heading line
 ; and type `C-c C-c' (pages-directory-goto) to go to the entry to
--- a/lisp/textmodes/texinfmt.el	Fri Jan 05 21:57:54 1996 +0000
+++ b/lisp/textmodes/texinfmt.el	Fri Jan 05 22:21:28 1996 +0000
@@ -2893,7 +2893,7 @@
 ;; In the original version, include files were ignored by Info but
 ;; incorporated in to the printed manual.  To make references to the
 ;; included file, the Texinfo source file has to refer to the included
-;; files using the `(filename)nodename' format for refering to other
+;; files using the `(filename)nodename' format for referring to other
 ;; Info files.  Also, the included files had to be formatted on their
 ;; own.  It was just like they were another file.
 
--- a/lisp/vc-hooks.el	Fri Jan 05 21:57:54 1996 +0000
+++ b/lisp/vc-hooks.el	Fri Jan 05 22:21:28 1996 +0000
@@ -183,7 +183,7 @@
   ;; Insert the contents of FILE into the current buffer.
   ;; Optional argument LIMIT is a regexp. If present,
   ;; the file is inserted in chunks of size BLOCKSIZE
-  ;; (default 8 kByte), until the first occurence of
+  ;; (default 8 kByte), until the first occurrence of
   ;; LIMIT is found. The function returns nil if FILE 
   ;; doesn't exist.
   (erase-buffer)
--- a/lisp/vc.el	Fri Jan 05 21:57:54 1996 +0000
+++ b/lisp/vc.el	Fri Jan 05 22:21:28 1996 +0000
@@ -827,7 +827,7 @@
 
 (defun vc-resynch-window (file &optional keep noquery)
   ;; If the given file is in the current buffer,
-  ;; either revert on it so we see expanded keyworks,
+  ;; either revert on it so we see expanded keywords,
   ;; or unvisit it (depending on vc-keep-workfiles)
   ;; NOQUERY if non-nil inhibits confirmation for reverting.
   ;; NOQUERY should be t *only* if it is known the only difference
@@ -2006,7 +2006,7 @@
   ;; Automatically retrieves a read-only version of the file with
   ;; keywords expanded if vc-keep-workfiles is non-nil, otherwise
   ;; it deletes the workfile.
-  ;;   Adaption for RCS branch support: if this is an explicit checkin,
+  ;;   Adaptation for RCS branch support: if this is an explicit checkin,
   ;; or if the checkin creates a new branch, set the master file branch
   ;; accordingly.
   (message "Checking in %s..." file)
@@ -2418,7 +2418,7 @@
 ;;; during the entire execution of vc-next-action, or (b) detect and
 ;;; recover from errors resulting from dispatch on an out-of-date state.
 ;;; 
-;;; Alternative (a) appears to be unfeasible.  The problem is that we can't
+;;; Alternative (a) appears to be infeasible.  The problem is that we can't
 ;;; guarantee that the lock will ever be removed.  Suppose a user starts a
 ;;; checkin, the change message buffer pops up, and the user, having wandered
 ;;; off to do something else, simply forgets about it?
--- a/lisp/ediff.el	Fri Jan 05 21:57:54 1996 +0000
+++ b/lisp/ediff.el	Fri Jan 05 22:21:28 1996 +0000
@@ -85,7 +85,7 @@
 
 ;;  2. On a monochrome display, the repertoire of faces with which to
 ;;  highlight fine differences is limited. By default, Ediff is using
-;;  underlining. However, if the region is already underlied by some other
+;;  underlining. However, if the region is already underlined by some other
 ;;  overlays, there is no simple way to temporarily remove that residual
 ;;  underlining. This problem occurs when a buffer is highlighted with
 ;;  hilit19.el or font-lock.el packages. If this residual highlighting gets
@@ -175,7 +175,7 @@
     ;; Make a temp file, if source-filename has a magic file handler (or if
     ;; it is handled via auto-mode-alist and similar magic).
     ;; Check if there is a buffer visiting source-filename and if they are in
     ;; synch; arrange for the deletion of temp file.
     (ediff-find-file 'true-source-filename 'buf-to-patch
 		     'ediff-last-dir-patch 'startup-hooks)
 
@@ -833,7 +833,7 @@
     
     (save-excursion
       (save-window-excursion
-	(sit-for 0) ; synch before using window-start/end -- a precaution
+	(sit-for 0) ; sync before using window-start/end -- a precaution
 	(select-window wind-A)
 	(setq beg-A (window-start)
 	      end-A (window-end))
@@ -175,7 +175,7 @@
     ;; it is handled via auto-mode-alist and similar magic).
     ;; Check if there is a buffer visiting source-filename and if they are in
-    ;; synch; arrange for the deletion of temp file.
+    ;; sync; arrange for the deletion of temp file.
     (ediff-find-file 'true-source-filename 'buf-to-patch
 		     'ediff-last-dir-patch 'startup-hooks)